@@ -1,10 +1,8 @@
-import os.path
 import sys
 import unittest
 import importlib_resources as resources
 import uuid
-
-from importlib_resources._compat import Path
+import pathlib
 
 from . import data01
 from . import zipdata01, zipdata02
@@ -29,20 +27,21 @@ class ResourceTests:
     def test_contents(self):
         contents = set(resources.contents(self.data))
         # There may be cruft in the directory listing of the data directory.
-        # Under Python 3 we could have a __pycache__ directory, and under
-        # Python 2 we could have .pyc files.  These are both artifacts of the
-        # test suite importing these modules and writing these caches.  They
-        # aren't germane to this test, so just filter them out.
+        # It could have a __pycache__ directory,
+        # an artifact of the
+        # test suite importing these modules, which
+        # are not germane to this test, so just filter them out.
         contents.discard('__pycache__')
-        contents.discard('__init__.pyc')
-        contents.discard('__init__.pyo')
-        self.assertEqual(contents, {
-            '__init__.py',
-            'subdirectory',
-            'utf-8.file',
-            'binary.file',
-            'utf-16.file',
-            })
+        self.assertEqual(
+            sorted(contents),
+            [
+                '__init__.py',
+                'binary.file',
+                'subdirectory',
+                'utf-16.file',
+                'utf-8.file',
+            ],
+        )
 
 
 class ResourceDiskTests(ResourceTests, unittest.TestCase):
@@ -54,31 +53,29 @@ class ResourceZipTests(ResourceTests, util.ZipSetup, unittest.TestCase):
     pass
 
 
-@unittest.skipIf(sys.version_info < (3,), 'No ResourceReader in Python 2')
 class ResourceLoaderTests(unittest.TestCase):
     def test_resource_contents(self):
         package = util.create_package(
-            file=data01, path=data01.__file__, contents=['A', 'B', 'C'])
-        self.assertEqual(
-            set(resources.contents(package)),
-            {'A', 'B', 'C'})
+            file=data01, path=data01.__file__, contents=['A', 'B', 'C']
+        )
+        self.assertEqual(set(resources.contents(package)), {'A', 'B', 'C'})
 
     def test_resource_is_resource(self):
         package = util.create_package(
-            file=data01, path=data01.__file__,
-            contents=['A', 'B', 'C', 'D/E', 'D/F'])
+            file=data01, path=data01.__file__, contents=['A', 'B', 'C', 'D/E', 'D/F']
+        )
         self.assertTrue(resources.is_resource(package, 'B'))
 
     def test_resource_directory_is_not_resource(self):
         package = util.create_package(
-            file=data01, path=data01.__file__,
-            contents=['A', 'B', 'C', 'D/E', 'D/F'])
+            file=data01, path=data01.__file__, contents=['A', 'B', 'C', 'D/E', 'D/F']
+        )
         self.assertFalse(resources.is_resource(package, 'D'))
 
     def test_resource_missing_is_not_resource(self):
         package = util.create_package(
-            file=data01, path=data01.__file__,
-            contents=['A', 'B', 'C', 'D/E', 'D/F'])
+            file=data01, path=data01.__file__, contents=['A', 'B', 'C', 'D/E', 'D/F']
+        )
         self.assertFalse(resources.is_resource(package, 'Z'))
 
 
@@ -89,43 +86,44 @@ class ResourceCornerCaseTests(unittest.TestCase):
         # 2. Are not on the file system
         # 3. Are not in a zip file
         module = util.create_package(
-            file=data01, path=data01.__file__, contents=['A', 'B', 'C'])
+            file=data01, path=data01.__file__, contents=['A', 'B', 'C']
+        )
         # Give the module a dummy loader.
         module.__loader__ = object()
         # Give the module a dummy origin.
         module.__file__ = '/path/which/shall/not/be/named'
-        if sys.version_info >= (3,):
-            module.__spec__.loader = module.__loader__
-            module.__spec__.origin = module.__file__
+        module.__spec__.loader = module.__loader__
+        module.__spec__.origin = module.__file__
         self.assertFalse(resources.is_resource(module, 'A'))
 
 
 class ResourceFromZipsTest01(util.ZipSetupBase, unittest.TestCase):
-    ZIP_MODULE = zipdata01                          # type: ignore
+    ZIP_MODULE = zipdata01  # type: ignore
 
     def test_is_submodule_resource(self):
         submodule = import_module('ziptestdata.subdirectory')
-        self.assertTrue(
-            resources.is_resource(submodule, 'binary.file'))
+        self.assertTrue(resources.is_resource(submodule, 'binary.file'))
 
     def test_read_submodule_resource_by_name(self):
         self.assertTrue(
-            resources.is_resource('ziptestdata.subdirectory', 'binary.file'))
+            resources.is_resource('ziptestdata.subdirectory', 'binary.file')
+        )
 
     def test_submodule_contents(self):
         submodule = import_module('ziptestdata.subdirectory')
         self.assertEqual(
-            set(resources.contents(submodule)),
-            {'__init__.py', 'binary.file'})
+            set(resources.contents(submodule)), {'__init__.py', 'binary.file'}
+        )
 
     def test_submodule_contents_by_name(self):
         self.assertEqual(
             set(resources.contents('ziptestdata.subdirectory')),
-            {'__init__.py', 'binary.file'})
+            {'__init__.py', 'binary.file'},
+        )
 
 
 class ResourceFromZipsTest02(util.ZipSetupBase, unittest.TestCase):
-    ZIP_MODULE = zipdata02                          # type: ignore
+    ZIP_MODULE = zipdata02  # type: ignore
 
     def test_unrelated_contents(self):
         """
@@ -133,27 +131,28 @@ class ResourceFromZipsTest02(util.ZipSetupBase, unittest.TestCase):
         distinct resources. Ref python/importlib_resources#44.
         """
         self.assertEqual(
-            set(resources.contents('ziptestdata.one')),
-            {'__init__.py', 'resource1.txt'})
+            set(resources.contents('ziptestdata.one')), {'__init__.py', 'resource1.txt'}
+        )
         self.assertEqual(
-            set(resources.contents('ziptestdata.two')),
-            {'__init__.py', 'resource2.txt'})
+            set(resources.contents('ziptestdata.two')), {'__init__.py', 'resource2.txt'}
+        )
 
 
 class DeletingZipsTest(unittest.TestCase):
     """Having accessed resources in a zip file should not keep an open
     reference to the zip.
     """
+
     ZIP_MODULE = zipdata01
 
     def setUp(self):
         modules = import_helper.modules_setup()
         self.addCleanup(import_helper.modules_cleanup, *modules)
 
-        data_path = Path(self.ZIP_MODULE.__file__)
+        data_path = pathlib.Path(self.ZIP_MODULE.__file__)
         data_dir = data_path.parent
         self.source_zip_path = data_dir / 'ziptestdata.zip'
-        self.zip_path = Path('{}.zip'.format(uuid.uuid4())).absolute()
+        self.zip_path = pathlib.Path(f'{uuid.uuid4()}.zip').absolute()
         self.zip_path.write_bytes(self.source_zip_path.read_bytes())
         sys.path.append(str(self.zip_path))
         self.data = import_module('ziptestdata')
@@ -215,23 +214,24 @@ class DeletingZipsTest(unittest.TestCase):
         del c
 
 
-@unittest.skipUnless(
-    sys.version_info[0] >= 3,
-    'namespace packages not available on Python 2'
-    )
 class ResourceFromNamespaceTest01(unittest.TestCase):
+    site_dir = str(pathlib.Path(__file__).parent)
+
     @classmethod
     def setUpClass(cls):
-        sys.path.append(os.path.abspath(os.path.join(__file__, '..')))
+        sys.path.append(cls.site_dir)
+
+    @classmethod
+    def tearDownClass(cls):
+        sys.path.remove(cls.site_dir)
 
     def test_is_submodule_resource(self):
         self.assertTrue(
-            resources.is_resource(
-                import_module('namespacedata01'), 'binary.file'))
+            resources.is_resource(import_module('namespacedata01'), 'binary.file')
+        )
 
     def test_read_submodule_resource_by_name(self):
-        self.assertTrue(
-            resources.is_resource('namespacedata01', 'binary.file'))
+        self.assertTrue(resources.is_resource('namespacedata01', 'binary.file'))
 
     def test_submodule_contents(self):
         contents = set(resources.contents(import_module('namespacedata01')))
@@ -239,8 +239,7 @@ class ResourceFromNamespaceTest01(unittest.TestCase):
             contents.remove('__pycache__')
         except KeyError:
             pass
-        self.assertEqual(
-            contents, {'binary.file', 'utf-8.file', 'utf-16.file'})
+        self.assertEqual(contents, {'binary.file', 'utf-8.file', 'utf-16.file'})
 
     def test_submodule_contents_by_name(self):
         contents = set(resources.contents('namespacedata01'))
@@ -248,8 +247,7 @@ class ResourceFromNamespaceTest01(unittest.TestCase):
             contents.remove('__pycache__')
         except KeyError:
             pass
-        self.assertEqual(
-            contents, {'binary.file', 'utf-8.file', 'utf-16.file'})
+        self.assertEqual(contents, {'binary.file', 'utf-8.file', 'utf-16.file'})
 
 
 if __name__ == '__main__':
